/**
 * A `<details>` element packaged nicely to animate like a disclosure.
 * @customElement
 * @tagName light-disclosure
 */
export class LightDisclosure extends BaseElement {
    static styles: import("lit").CSSResult[];
    static properties: {
        summary: {};
        open: {
            type: BooleanConstructor;
        };
    };
    /**
     * @type {string}
     */
    summary: string;
    /**
     * @type {boolean}
     */
    open: boolean;
    /**
     * @internal
     * This is used because Safari has strange timing on the "toggle" event. If we don't use this,
     *   our initial opening of the disclosure gets clipped and is like a normal `<details>`
     */
    _openOnToggle: boolean;
    /**
     * @param {import("lit").PropertyValues<this>} changedProperties
     */
    willUpdate(changedProperties: import("lit").PropertyValues<this>): void;
    render(): import("lit").TemplateResult<1>;
    get details(): HTMLDetailsElement | null | undefined;
    /**
     * @param {TransitionEvent} e
     */
    handleTransitionEnd(e: TransitionEvent): void;
    /**
     * Toggle fires after the attribute is set / unset, so its useless for expanded. But useful for when users search a page with "ctrl+f"
     * @param {Event} _e
     */
    handleToggle(_e: Event): void;
    /**
     * @param {Event} e
     */
    handleSummaryClick(e: Event): false | undefined;
}
import { BaseElement } from "../internal/base-element.js";
