/**
 * @typedef {import("prismjs").hooks.TokenizeEnvironment & { tokens: Array<string | Token>}} Env
 * @typedef {import("prismjs").hooks.HookCallback} HookCallback
 */
/**
 * Custom hooks to run with our custom tokenizer.
 * @typedef {Object} Hooks
 * @property {Hook[]} [beforeTokenize]
 * @property {Hook[]} [afterTokenize]
 */
/**
 * Custom hooks to run with our custom tokenizer.
 * @typedef {(env: Env) => void} Hook
 */
/**
 * @see https://github.com/PrismJS/prism/blob/59e5a3471377057de1f401ba38337aca27b80e03/prism.js#L660
 * A forked function from PrismJS to make wrap the tokenizer with custom functionality.
 * @param {string} text - The code to highlight
 * @param {import("prismjs").Grammar} grammar - The grammar to use
 * @param {string} language - The language to detect
 * @param {Hooks} hooks
 */
export function PrismHighlight(text: string, grammar: import("prismjs").Grammar, language: string, hooks?: Hooks): string;
export { PrismJS };
export type Env = import("prismjs").hooks.TokenizeEnvironment & {
    tokens: Array<string | Token>;
};
export type HookCallback = import("prismjs").hooks.HookCallback;
/**
 * Custom hooks to run with our custom tokenizer.
 */
export type Hooks = {
    beforeTokenize?: Hook[] | undefined;
    afterTokenize?: Hook[] | undefined;
};
/**
 * Custom hooks to run with our custom tokenizer.
 */
export type Hook = (env: Env) => void;
import PrismJS from "prismjs";
import { Token } from "prismjs";
